@@ -248,9 +248,6 @@ class GlobalConfig(Gtk.Application):
         """
         The function that performs actual widget realization and setup.
         """
-        self.progress_bar_dialog.show()
-        self.progress_bar_dialog.update_progress(0)
-
         self.builder = Gtk.Builder()
         glade_ref = (importlib.resources.files('qubes_config') /
                      'global_config.glade')
@@ -266,6 +263,9 @@ class GlobalConfig(Gtk.Application):
                    light_file_name='qubes-global-config-light.css',
                    dark_file_name='qubes-global-config-dark.css')
 
+        self.progress_bar_dialog.show_all()
+        self.progress_bar_dialog.update_progress(0)
+
         self.apply_button: Gtk.Button = self.builder.get_object('apply_button')
         self.cancel_button: Gtk.Button = \
             self.builder.get_object('cancel_button')
@@ -362,6 +362,12 @@ class GlobalConfig(Gtk.Application):
              self.builder.get_object('thisdevice_scrolled_window'),
              ])
 
+        # workaround the uncomfortable behavior with comboboxes: combobox
+        # should not change item ID on random scrolling around
+        for obj in self.builder.get_objects():
+            if isinstance(obj, (Gtk.ComboBox, Gtk.ComboBoxText)):
+                obj.connect("scroll-event", lambda *args: True)
+
         self.progress_bar_dialog.update_progress(1)
         self.progress_bar_dialog.hide()
         self.progress_bar_dialog.destroy()
@@ -491,11 +497,47 @@ class GlobalConfig(Gtk.Application):
         return False
 
 
+class VMCollection(qubesadmin.app.VMCollection):
+    """
+    Overloaded class to get rid of volatile disposables
+    """
+
+    def __iter__(self):
+        for vm in super().__iter__():
+            try:
+                if vm.klass == "DispVM" and vm.auto_cleanup:
+                    continue
+            except:  # pylint: disable=bare-except
+                continue
+            yield vm
+
+
+class Qubes(qubesadmin.Qubes):
+    """
+    Overloaded class to get rid of volatile disposables
+    """
+
+    # Auxiliary domains collection which excludes true disposables (not named)
+    _domains = None
+
+    def __init__(self):
+        super().__init__()
+        self._domains = VMCollection(self)
+
+    @property
+    def domains(self):
+        return self._domains
+
+    @domains.setter
+    def domains(self, d):
+        self._domains = d
+
+
 def main():
     """
     Start the app
     """
-    qapp = qubesadmin.Qubes()
+    qapp = Qubes()
     qapp.cache_enabled = True
     policy_manager = PolicyManager()
     app = GlobalConfig(qapp, policy_manager)
