@@ -89,9 +89,6 @@ class CreateNewQube(Gtk.Application):
         The function that performs actual widget realization and setup. Should
         be only called once, in the main instance of this application.
         """
-        self.progress_bar_dialog.show()
-        self.progress_bar_dialog.update_progress(0.1)
-
         self.builder = Gtk.Builder()
         glade_ref = (importlib.resources.files('qubes_config') /
                      'new_qube.glade')
@@ -108,6 +105,7 @@ class CreateNewQube(Gtk.Application):
                    light_file_name='qubes-new-qube-light.css',
                    dark_file_name='qubes-new-qube-dark.css')
 
+        self.progress_bar_dialog.show_all()
         self.progress_bar_dialog.update_progress(0.1)
 
         self.template_handler = TemplateHandler(self.builder, self.qapp)
@@ -151,6 +149,7 @@ class CreateNewQube(Gtk.Application):
         )
 
         self.qube_name.connect('changed', self._name_changed)
+        self.qube_name.connect("focus-out-event", self._name_changed)
 
         self.progress_bar_dialog.update_progress(0.1)
 
@@ -183,6 +182,8 @@ class CreateNewQube(Gtk.Application):
         self.progress_bar_dialog.update_progress(1)
         self.progress_bar_dialog.hide()
 
+        self.main_window.set_focus(self.qube_name)
+
     def _quit(self, *_args):
         self.quit()
 
@@ -193,11 +194,14 @@ class CreateNewQube(Gtk.Application):
                            Gtk.Window,
                            GObject.SignalFlags.RUN_LAST, None, (str,))
 
-    def _name_changed(self, entry: Gtk.Entry):
+    def _name_changed(self, entry: Gtk.Entry, event=None):
+        # pylint: disable=unused-argument
         if not entry.get_text():
             self.create_button.set_sensitive(False)
+            self.qube_name.get_style_context().add_class("invalid_entry")
         else:
             self.create_button.set_sensitive(True)
+            self.qube_name.get_style_context().remove_class("invalid_entry")
 
     def _type_selected(self, button: Gtk.RadioButton):
         button_name = button.get_name()
@@ -206,6 +210,12 @@ class CreateNewQube(Gtk.Application):
                 load_icon('qubes-question', 20, 20))
             return
         self.template_handler.change_vm_type(button_name)
+
+        if button_name == 'qube_type_template':
+            self.network_selector.network_none.set_active(True)
+        else:
+            self.network_selector.network_default.set_active(True)
+
         self.tooltips[button_name].set_from_pixbuf(load_icon(
                 'qubes-question-light', 20, 20))
 
@@ -227,8 +237,10 @@ class CreateNewQube(Gtk.Application):
 
         properties: Dict[str, Any] = {'provides_network':
                           self.advanced_handler.get_provides_network()}
-        if self.network_selector.get_selected_netvm() != qubesadmin.DEFAULT:
-            properties['netvm'] = self.network_selector.get_selected_netvm()
+        selected_netvm = self.network_selector.get_selected_netvm()
+        if not (klass == 'TemplateVM' and selected_netvm is None) \
+                and selected_netvm != qubesadmin.DEFAULT:
+            properties['netvm'] = selected_netvm
         if klass == 'StandaloneVM' and \
                 not self.template_handler.get_selected_template():
             properties['virt_mode'] = 'hvm'
