@@ -339,6 +339,7 @@ class PolicyEditor(Gtk.Application):
             self.source_view.get_input_hints() | Gtk.InputHints.NO_EMOJI)
         self.source_view.set_monospace(True)
         self.source_buffer.connect('changed', self._text_changed)
+        self.source_buffer.connect("modified-changed", self._text_changed)
         self.source_buffer.get_undo_manager().connect('can-redo-changed',
                                                       self._redo_changed)
         self.source_buffer.get_undo_manager().connect('can-undo-changed',
@@ -406,7 +407,7 @@ class PolicyEditor(Gtk.Application):
             ask_dialog.destroy()
 
         # validation - only alphanumerics and - _
-        if not re.compile(r'[\w-]+').match(new_name):
+        if not re.compile(r'^[\w-]+$').match(new_name):
             show_error(self.main_window, "Invalid policy file name",
                        f"Invalid policy file name: {new_name}. Policy file "
                        "names must contain only alphanumeric characters, "
