@@ -80,6 +80,7 @@ default_vm_properties = {
     "management_dispvm": ("vm", True, "default-mgmt-dvm"),
     "netvm": ("vm", False, "sys-firewall"),
     "template": ("vm", False, "fedora-36"),
+    "auto_cleanup": ("bool", True, "False"),
 }
 
 possible_tags = ['whonix-updatevm', 'anon-gateway']
@@ -281,6 +282,16 @@ def test_qapp_impl():
                     {'template_for_dispvms': ('bool', False, 'True')},
                     {'service.qubes-update-check': None}, [])
 
+    # This DispVM will die suddently in the middle of Global Config running
+    add_expected_vm(
+        qapp,
+        "disp666",
+        "DispVM",
+        {},
+        {"service.qubes-update-check": None},
+        [],
+    )
+
     add_expected_vm(qapp, 'test-vm', 'AppVM',
                     {}, {'service.qubes-update-check': None}, [])
 
