@@ -21,8 +21,14 @@ import gi  # isort:skip
 gi.require_version('Gtk', '3.0')  # isort:skip
 from gi.repository import Gio, Gtk, GObject, GLib, GdkPixbuf  # isort:skip
 
-import gbulb
-gbulb.install()
+try:
+    from gi.events import GLibEventLoopPolicy
+
+    asyncio.set_event_loop_policy(GLibEventLoopPolicy())
+except ImportError:
+    import gbulb
+
+    gbulb.install()
 
 import gettext
 t = gettext.translation("desktop-linux-manager", fallback=True)
@@ -756,7 +762,9 @@ class DomainTray(Gtk.Application):
 
     def handle_domain_shutdown(self, vm):
         try:
-            if getattr(vm, 'klass', None) == 'TemplateVM':
+            if getattr(vm, "klass", None) == "TemplateVM" or getattr(
+                vm, "template_for_dispvms", False
+            ):
                 for menu_item in self.menu_items.values():
                     try:
                         if not menu_item.vm.is_running():
@@ -765,9 +773,12 @@ class DomainTray(Gtk.Application):
                             continue
                     except exc.QubesPropertyAccessError:
                         continue
-                    if getattr(menu_item.vm, 'template', None) == vm and \
-                            any(vol.is_outdated()
-                                for vol in menu_item.vm.volumes.values()):
+                    template1 = getattr(menu_item.vm, "template", None)
+                    template2 = getattr(template1, "template", None)
+                    if vm in (template1, template2) and any(
+                        vol.is_outdated()
+                        for vol in menu_item.vm.volumes.values()
+                    ):
                         menu_item.name.update_outdated(True)
         except exc.QubesVMNotFoundError:
             # attribute not available anymore as VM was removed
