@@ -199,9 +199,16 @@ class QubesUpdater(Gtk.Application):
             self.log.info("Show intro page.")
         self.main_window.show_all()
         width = self.intro_page.vm_list.get_preferred_width().natural_width
-        height = min(int(width * 1.2),
-            self.main_window.get_screen().get_height() - 48)
+        # Wide enough for details section to show update progress.
+        # But still less than 1024 pixels to do not break OpenQA tests.
+        screen = self.main_window.get_screen()
+        width = max(width, 1000)
+        width = min(width, screen.get_width() - 12)
+        height = min(int(width * 1.2), screen.get_height() - 100)
         self.main_window.resize(width + 50, height)
+        if screen.get_width() <= 1024 or screen.get_height() < 768:
+            self.main_window.maximize()
+        self.main_window.set_size_request(800, 600)  # Smaller is meaningless
         self.main_window.set_position(Gtk.WindowPosition.CENTER_ALWAYS)
 
     def open_settings_window(self, _emitter):
@@ -361,9 +368,11 @@ def parse_args(args, app):
         action='store_true',
         help='Restart not updated ServiceVMs whose template has been updated.')
     restart.add_argument(
-        '--apply-to-all', '-R', action='store_true',
-        help='Restart not updated ServiceVMs and shutdown not updated AppVMs '
-             'whose template has been updated.')
+        "--apply-to-all",
+        "-R",
+        action="store_true",
+        help="Restart service qubes and AppVMs with updated templates.",
+    )
     restart.add_argument(
         '--no-apply', action='store_true',
         help='DEFAULT. Do not restart/shutdown any AppVMs.')
